Index: lib/filterClasses.js |
diff --git a/lib/filterClasses.js b/lib/filterClasses.js |
index 1c990c1992d34238ef220ced3bc6f27308fa6163..71f1701c752e124cfb2324ddfb9cee97f174b652 100644 |
--- a/lib/filterClasses.js |
+++ b/lib/filterClasses.js |
@@ -749,11 +749,16 @@ RegExpFilter.typeMap = { |
BACKGROUND: 4, // Backwards compat, same as IMAGE |
POPUP: 0x10000000, |
- ELEMHIDE: 0x40000000 |
+ GENERICBLOCK: 0x20000000, |
+ ELEMHIDE: 0x40000000, |
+ GENERICHIDE: 0x80000000 |
}; |
-// ELEMHIDE, POPUP option shouldn't be there by default |
-RegExpFilter.prototype.contentType &= ~(RegExpFilter.typeMap.ELEMHIDE | RegExpFilter.typeMap.POPUP); |
+// ELEMHIDE, POPUP, GENERICHIDE and GENERICBLOCK options shouldn't be there by default |
+RegExpFilter.prototype.contentType &= ~(RegExpFilter.typeMap.ELEMHIDE | |
+ RegExpFilter.typeMap.POPUP | |
+ RegExpFilter.typeMap.GENERICHIDE | |
+ RegExpFilter.typeMap.GENERICBLOCK); |
/** |
* Class for blocking filters |